<p align="center">
  <img src="https://s3.amazonaws.com/howler.js/phaser-webpack-loader.png" alt="Phaser Webpack Loader">
</p>

# Phaser Webpack Loader
Instead of manually calling `game.load.image`, `game.load.audio`, etc for every asset in your game (and then dealing with caching issues), phaser-webpack-loader lets you define all assets in a simple manifest file and handles the rest for you.

View sample usage in this [Phaser ES6 Boilerplate](https://github.com/goldfire/phaser-boilerplate).

## Features

* Load all game assets in parallel.
* Load images, spritesheets, atlases, audio, bitmap fonts and web fonts.
* Integrated with Webpack for automatic cache-busting.
* Supports all filetypes.

## Install

Install the plugin through NPM (or Yarn):

```
npm install phaser-webpack-loader --save
```

Then create your manifest file and add the plugin as outlined below.

## Manifest File (AssetManifest.js)

```javascript
const AssetManifest = {
  images: [
    'image001.png',
    'image002.jpg',
    '...',
  ],
  sprites: [
    'sprite001.png',
    'sprite002.png',
    '...',
  ],
  audio: [
    'audio001.webm',
    'audio002.mp3',
    '...',
  ],
  bitmapFonts: [
    'font001.png',
    'font002.png',
    '...',
  ],
  fonts: {
    google: {
      families: [
        'Open Sans:300,700',
      ],
    },
  },
};

export default AssetManifest;
```

Then, specify the base directory in your Webpack config:

```
resolve: {
    alias: {
      assets: path.join(__dirname, '../src/assets'),
    },
  },
```

## Running Plugin (Preload.js)

In your preload state, add the plugin. It uses promises, which makes it flexible to move to the next step when ready.

```javascript
import WebpackLoader from 'phaser-webpack-loader';
import AssetManifest from '../AssetManifest';

export default class Preload extends Phaser.State {
  create() {
    this.game.plugins.add(WebpackLoader, AssetManifest)
      .load()
      .then(() => {
        this.game.state.start('Main');
      });
  }
}
```

## Loading Fonts

The font loader uses [Web Font Loader](https://github.com/typekit/webfontloader), which supports loading web fonts from all major providers. Simply provide their standard configuration object in your manifest.

## Loading Sprites/Atlases

All sprite/atlas files are loaded as JSON hashes (which can be output using [TexturePacker](https://www.codeandweb.com/texturepacker), [Shoebox](http://renderhjs.net/shoebox/) and others). All you have to specify in the manifest is the image filename, but you'll also need to include the JSON hash file alongside it, which will automatically get loaded and used.

## Directory Structure

You can specify whatever base directory you would like in the manifest file, but then each asset type should go as follows:

```
assets/
├── images/
├── sprites/
├── audio/
└── fonts/
```

### License

Copyright (c) 2017 [James Simpson](https://twitter.com/GoldFireStudios) and [GoldFire Studios, Inc.](http://goldfirestudios.com)

Released under the [MIT License](https://github.com/goldfire/phaser-webpack-loader/blob/master/LICENSE.md).